@@ -64,7 +64,7 @@ source_files = function(format = NULL, config = load_config(), all = FALSE) {
     if (is.character(subdir)) subdir else '.', '[.]Rmd$', ignore.case = TRUE,
     recursive = subdir_yes, full.names = subdir_yes
   ))
-  if (length(files2 <- config[['rmd_files']]) > 0 && !is.null(format)) {
+  if (length(files2 <- config[['rmd_files']]) > 0) {
     if (is.list(files2)) files2 = if (all) unlist(files2) else files2[[format]]
     files = if (subdir_yes) c(files2, files) else files2
   } else {
@@ -357,9 +357,11 @@ existing_r = function(base, first = FALSE) {
   existing_files(x, first)
 }
 
-html_or_latex = function(format) {
-  if (grepl('(html|gitbook|epub)', format)) return('html')
+target_format = function(format) {
+  if (grepl('(html|gitbook)', format)) return('html')
   if (grepl('pdf', format)) return('latex')
+  if (grepl('epub_', format)) return('epub')
+  if (grepl('word_', format)) return('docx')
   switch(format, tufte_book2 = 'latex', tufte_handout2 = 'latex')
 }
 
